Documentation
¶
Index ¶
- Constants
- Variables
- type Blob
- func (*Blob) Descriptor() ([]byte, []int)deprecated
- func (m *Blob) GetData() isBlob_Data
- func (x *Blob) GetLz4Data() []byte
- func (x *Blob) GetLzmaData() []byte
- func (x *Blob) GetOBSOLETEBzip2Data() []bytedeprecated
- func (x *Blob) GetRaw() []byte
- func (x *Blob) GetRawSize() int32
- func (x *Blob) GetZlibData() []byte
- func (x *Blob) GetZstdData() []byte
- func (*Blob) ProtoMessage()
- func (x *Blob) ProtoReflect() protoreflect.Message
- func (x *Blob) Reset()
- func (x *Blob) String() string
- func (m *Blob) UnmarshalVT(dAtA []byte) error
- type BlobHeader
- func (*BlobHeader) Descriptor() ([]byte, []int)deprecated
- func (x *BlobHeader) GetDatasize() int32
- func (x *BlobHeader) GetType() string
- func (*BlobHeader) ProtoMessage()
- func (x *BlobHeader) ProtoReflect() protoreflect.Message
- func (x *BlobHeader) Reset()
- func (x *BlobHeader) String() string
- func (m *BlobHeader) UnmarshalVT(dAtA []byte) error
- type Blob_Lz4Data
- type Blob_LzmaData
- type Blob_OBSOLETEBzip2Data
- type Blob_Raw
- type Blob_ZlibData
- type Blob_ZstdData
- type DenseNodes
- func (*DenseNodes) Descriptor() ([]byte, []int)deprecated
- func (x *DenseNodes) GetId() []int64
- func (x *DenseNodes) GetKeysVals() []int32
- func (x *DenseNodes) GetLat() []int64
- func (x *DenseNodes) GetLon() []int64
- func (*DenseNodes) ProtoMessage()
- func (x *DenseNodes) ProtoReflect() protoreflect.Message
- func (x *DenseNodes) Reset()
- func (m *DenseNodes) ResetVT()
- func (m *DenseNodes) ReturnToVTPool()
- func (x *DenseNodes) String() string
- func (m *DenseNodes) UnmarshalVT(dAtA []byte) error
- type HeaderBlock
- func (*HeaderBlock) Descriptor() ([]byte, []int)deprecated
- func (x *HeaderBlock) GetOptionalFeatures() []string
- func (x *HeaderBlock) GetRequiredFeatures() []string
- func (*HeaderBlock) ProtoMessage()
- func (x *HeaderBlock) ProtoReflect() protoreflect.Message
- func (x *HeaderBlock) Reset()
- func (x *HeaderBlock) String() string
- func (m *HeaderBlock) UnmarshalVT(dAtA []byte) error
- type Node
- func (*Node) Descriptor() ([]byte, []int)deprecated
- func (x *Node) GetId() int64
- func (x *Node) GetKeys() []uint32
- func (x *Node) GetLat() int64
- func (x *Node) GetLon() int64
- func (x *Node) GetVals() []uint32
- func (*Node) ProtoMessage()
- func (x *Node) ProtoReflect() protoreflect.Message
- func (x *Node) Reset()
- func (m *Node) ResetVT()
- func (m *Node) ReturnToVTPool()
- func (x *Node) String() string
- func (m *Node) UnmarshalVT(dAtA []byte) error
- type PrimitiveBlock
- func (*PrimitiveBlock) Descriptor() ([]byte, []int)deprecated
- func (x *PrimitiveBlock) GetGranularity() int32
- func (x *PrimitiveBlock) GetLatOffset() int64
- func (x *PrimitiveBlock) GetLonOffset() int64
- func (x *PrimitiveBlock) GetPrimitivegroup() []*PrimitiveGroup
- func (x *PrimitiveBlock) GetStringtable() *StringTable
- func (*PrimitiveBlock) ProtoMessage()
- func (x *PrimitiveBlock) ProtoReflect() protoreflect.Message
- func (x *PrimitiveBlock) Reset()
- func (m *PrimitiveBlock) ResetVT()
- func (m *PrimitiveBlock) ReturnToVTPool()
- func (x *PrimitiveBlock) String() string
- func (m *PrimitiveBlock) UnmarshalVT(dAtA []byte) error
- type PrimitiveGroup
- func (*PrimitiveGroup) Descriptor() ([]byte, []int)deprecated
- func (x *PrimitiveGroup) GetDense() *DenseNodes
- func (x *PrimitiveGroup) GetNodes() []*Node
- func (x *PrimitiveGroup) GetRelations() []*Relation
- func (x *PrimitiveGroup) GetWays() []*Way
- func (*PrimitiveGroup) ProtoMessage()
- func (x *PrimitiveGroup) ProtoReflect() protoreflect.Message
- func (x *PrimitiveGroup) Reset()
- func (m *PrimitiveGroup) ResetVT()
- func (m *PrimitiveGroup) ReturnToVTPool()
- func (x *PrimitiveGroup) String() string
- func (m *PrimitiveGroup) UnmarshalVT(dAtA []byte) error
- type Relation
- func (*Relation) Descriptor() ([]byte, []int)deprecated
- func (x *Relation) GetId() int64
- func (x *Relation) GetKeys() []uint32
- func (x *Relation) GetMemids() []int64
- func (x *Relation) GetRolesSid() []int32
- func (x *Relation) GetTypes() []Relation_MemberType
- func (x *Relation) GetVals() []uint32
- func (*Relation) ProtoMessage()
- func (x *Relation) ProtoReflect() protoreflect.Message
- func (x *Relation) Reset()
- func (m *Relation) ResetVT()
- func (m *Relation) ReturnToVTPool()
- func (x *Relation) String() string
- func (m *Relation) UnmarshalVT(dAtA []byte) error
- type Relation_MemberType
- func (Relation_MemberType) Descriptor() protoreflect.EnumDescriptor
- func (x Relation_MemberType) Enum() *Relation_MemberType
- func (Relation_MemberType) EnumDescriptor() ([]byte, []int)deprecated
- func (x Relation_MemberType) Number() protoreflect.EnumNumber
- func (x Relation_MemberType) String() string
- func (Relation_MemberType) Type() protoreflect.EnumType
- func (x *Relation_MemberType) UnmarshalJSON(b []byte) errordeprecated
- type StringTable
- func (*StringTable) Descriptor() ([]byte, []int)deprecated
- func (x *StringTable) GetS() [][]byte
- func (*StringTable) ProtoMessage()
- func (x *StringTable) ProtoReflect() protoreflect.Message
- func (x *StringTable) Reset()
- func (m *StringTable) ResetVT()
- func (m *StringTable) ReturnToVTPool()
- func (x *StringTable) String() string
- func (m *StringTable) UnmarshalVT(dAtA []byte) error
- type Way
- func (*Way) Descriptor() ([]byte, []int)deprecated
- func (x *Way) GetId() int64
- func (x *Way) GetKeys() []uint32
- func (x *Way) GetRefs() []int64
- func (x *Way) GetVals() []uint32
- func (*Way) ProtoMessage()
- func (x *Way) ProtoReflect() protoreflect.Message
- func (x *Way) Reset()
- func (m *Way) ResetVT()
- func (m *Way) ReturnToVTPool()
- func (x *Way) String() string
- func (m *Way) UnmarshalVT(dAtA []byte) error
Constants ¶
const ( Default_PrimitiveBlock_Granularity = int32(100) Default_PrimitiveBlock_LatOffset = int64(0) Default_PrimitiveBlock_LonOffset = int64(0) )
Default values for PrimitiveBlock fields.
Variables ¶
var ( Relation_MemberType_name = map[int32]string{ 0: "NODE", 1: "WAY", 2: "RELATION", } Relation_MemberType_value = map[string]int32{ "NODE": 0, "WAY": 1, "RELATION": 2, } )
Enum value maps for Relation_MemberType.
var File_fileformat_proto protoreflect.FileDescriptor
var File_osmformat_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Blob ¶
type Blob struct {
RawSize *int32 `protobuf:"varint,2,opt,name=raw_size,json=rawSize" json:"raw_size,omitempty"` // When compressed, the uncompressed size
// Types that are assignable to Data:
//
// *Blob_Raw
// *Blob_ZlibData
// *Blob_LzmaData
// *Blob_OBSOLETEBzip2Data
// *Blob_Lz4Data
// *Blob_ZstdData
Data isBlob_Data `protobuf_oneof:"data"`
// contains filtered or unexported fields
}
func (*Blob) Descriptor
deprecated
func (*Blob) GetLz4Data ¶
func (*Blob) GetLzmaData ¶
func (*Blob) GetOBSOLETEBzip2Data
deprecated
func (*Blob) GetRawSize ¶
func (*Blob) GetZlibData ¶
func (*Blob) GetZstdData ¶
func (*Blob) ProtoMessage ¶
func (*Blob) ProtoMessage()
func (*Blob) ProtoReflect ¶
func (x *Blob) ProtoReflect() protoreflect.Message
func (*Blob) UnmarshalVT ¶
type BlobHeader ¶
type BlobHeader struct {
Type *string `protobuf:"bytes,1,req,name=type" json:"type,omitempty"`
// Not needed for now: optional bytes indexdata = 2;
Datasize *int32 `protobuf:"varint,3,req,name=datasize" json:"datasize,omitempty"`
// contains filtered or unexported fields
}
func (*BlobHeader) Descriptor
deprecated
func (*BlobHeader) Descriptor() ([]byte, []int)
Deprecated: Use BlobHeader.ProtoReflect.Descriptor instead.
func (*BlobHeader) GetDatasize ¶
func (x *BlobHeader) GetDatasize() int32
func (*BlobHeader) GetType ¶
func (x *BlobHeader) GetType() string
func (*BlobHeader) ProtoMessage ¶
func (*BlobHeader) ProtoMessage()
func (*BlobHeader) ProtoReflect ¶
func (x *BlobHeader) ProtoReflect() protoreflect.Message
func (*BlobHeader) Reset ¶
func (x *BlobHeader) Reset()
func (*BlobHeader) String ¶
func (x *BlobHeader) String() string
func (*BlobHeader) UnmarshalVT ¶
func (m *BlobHeader) UnmarshalVT(dAtA []byte) error
type Blob_Lz4Data ¶
type Blob_Lz4Data struct {
Lz4Data []byte `protobuf:"bytes,6,opt,name=lz4_data,json=lz4Data,oneof"` // For LZ4 compressed data (optional)
}
type Blob_LzmaData ¶
type Blob_LzmaData struct {
LzmaData []byte `protobuf:"bytes,4,opt,name=lzma_data,json=lzmaData,oneof"` // For LZMA compressed data (optional)
}
type Blob_OBSOLETEBzip2Data ¶
type Blob_OBSOLETEBzip2Data struct {
// Deprecated: Marked as deprecated in fileformat.proto.
OBSOLETEBzip2Data []byte `protobuf:"bytes,5,opt,name=OBSOLETE_bzip2_data,json=OBSOLETEBzip2Data,oneof"` // Formerly used for bzip2 compressed data. Deprecated in 2010.
}
type Blob_Raw ¶
type Blob_Raw struct {
Raw []byte `protobuf:"bytes,1,opt,name=raw,oneof"` // No compression
}
type Blob_ZlibData ¶
type Blob_ZlibData struct {
ZlibData []byte `protobuf:"bytes,3,opt,name=zlib_data,json=zlibData,oneof"` // Possible compressed versions of the data.
}
type Blob_ZstdData ¶
type Blob_ZstdData struct {
ZstdData []byte `protobuf:"bytes,7,opt,name=zstd_data,json=zstdData,oneof"` // For ZSTD compressed data (optional)
}
type DenseNodes ¶
type DenseNodes struct {
Id []int64 `protobuf:"zigzag64,1,rep,packed,name=id" json:"id,omitempty"` // DELTA coded
Lat []int64 `protobuf:"zigzag64,8,rep,packed,name=lat" json:"lat,omitempty"` // DELTA coded
Lon []int64 `protobuf:"zigzag64,9,rep,packed,name=lon" json:"lon,omitempty"` // DELTA coded
// Special packing of keys and vals into one array. May be empty if all nodes in this block are tagless.
KeysVals []int32 `protobuf:"varint,10,rep,packed,name=keys_vals,json=keysVals" json:"keys_vals,omitempty"`
// contains filtered or unexported fields
}
func DenseNodesFromVTPool ¶
func DenseNodesFromVTPool() *DenseNodes
func (*DenseNodes) Descriptor
deprecated
func (*DenseNodes) Descriptor() ([]byte, []int)
Deprecated: Use DenseNodes.ProtoReflect.Descriptor instead.
func (*DenseNodes) GetId ¶
func (x *DenseNodes) GetId() []int64
func (*DenseNodes) GetKeysVals ¶
func (x *DenseNodes) GetKeysVals() []int32
func (*DenseNodes) GetLat ¶
func (x *DenseNodes) GetLat() []int64
func (*DenseNodes) GetLon ¶
func (x *DenseNodes) GetLon() []int64
func (*DenseNodes) ProtoMessage ¶
func (*DenseNodes) ProtoMessage()
func (*DenseNodes) ProtoReflect ¶
func (x *DenseNodes) ProtoReflect() protoreflect.Message
func (*DenseNodes) Reset ¶
func (x *DenseNodes) Reset()
func (*DenseNodes) ResetVT ¶
func (m *DenseNodes) ResetVT()
func (*DenseNodes) ReturnToVTPool ¶
func (m *DenseNodes) ReturnToVTPool()
func (*DenseNodes) String ¶
func (x *DenseNodes) String() string
func (*DenseNodes) UnmarshalVT ¶
func (m *DenseNodes) UnmarshalVT(dAtA []byte) error
type HeaderBlock ¶
type HeaderBlock struct {
// Additional tags to aid in parsing this dataset
RequiredFeatures []string `protobuf:"bytes,4,rep,name=required_features,json=requiredFeatures" json:"required_features,omitempty"`
OptionalFeatures []string `protobuf:"bytes,5,rep,name=optional_features,json=optionalFeatures" json:"optional_features,omitempty"`
// contains filtered or unexported fields
}
func (*HeaderBlock) Descriptor
deprecated
func (*HeaderBlock) Descriptor() ([]byte, []int)
Deprecated: Use HeaderBlock.ProtoReflect.Descriptor instead.
func (*HeaderBlock) GetOptionalFeatures ¶
func (x *HeaderBlock) GetOptionalFeatures() []string
func (*HeaderBlock) GetRequiredFeatures ¶
func (x *HeaderBlock) GetRequiredFeatures() []string
func (*HeaderBlock) ProtoMessage ¶
func (*HeaderBlock) ProtoMessage()
func (*HeaderBlock) ProtoReflect ¶
func (x *HeaderBlock) ProtoReflect() protoreflect.Message
func (*HeaderBlock) Reset ¶
func (x *HeaderBlock) Reset()
func (*HeaderBlock) String ¶
func (x *HeaderBlock) String() string
func (*HeaderBlock) UnmarshalVT ¶
func (m *HeaderBlock) UnmarshalVT(dAtA []byte) error
type Node ¶
type Node struct {
Id *int64 `protobuf:"zigzag64,1,req,name=id" json:"id,omitempty"`
// Parallel arrays.
Keys []uint32 `protobuf:"varint,2,rep,packed,name=keys" json:"keys,omitempty"` // String IDs.
Vals []uint32 `protobuf:"varint,3,rep,packed,name=vals" json:"vals,omitempty"` // String IDs.
Lat *int64 `protobuf:"zigzag64,8,req,name=lat" json:"lat,omitempty"`
Lon *int64 `protobuf:"zigzag64,9,req,name=lon" json:"lon,omitempty"`
// contains filtered or unexported fields
}
func NodeFromVTPool ¶
func NodeFromVTPool() *Node
func (*Node) Descriptor
deprecated
func (*Node) ProtoMessage ¶
func (*Node) ProtoMessage()
func (*Node) ProtoReflect ¶
func (x *Node) ProtoReflect() protoreflect.Message
func (*Node) ReturnToVTPool ¶
func (m *Node) ReturnToVTPool()
func (*Node) UnmarshalVT ¶
type PrimitiveBlock ¶
type PrimitiveBlock struct {
Stringtable *StringTable `protobuf:"bytes,1,req,name=stringtable" json:"stringtable,omitempty"`
Primitivegroup []*PrimitiveGroup `protobuf:"bytes,2,rep,name=primitivegroup" json:"primitivegroup,omitempty"`
// Granularity, units of nanodegrees, used to store coordinates in this block.
Granularity *int32 `protobuf:"varint,17,opt,name=granularity,def=100" json:"granularity,omitempty"`
// Offset value between the output coordinates and the granularity grid in units of nanodegrees.
LatOffset *int64 `protobuf:"varint,19,opt,name=lat_offset,json=latOffset,def=0" json:"lat_offset,omitempty"`
LonOffset *int64 `protobuf:"varint,20,opt,name=lon_offset,json=lonOffset,def=0" json:"lon_offset,omitempty"`
// contains filtered or unexported fields
}
func PrimitiveBlockFromVTPool ¶
func PrimitiveBlockFromVTPool() *PrimitiveBlock
func (*PrimitiveBlock) Descriptor
deprecated
func (*PrimitiveBlock) Descriptor() ([]byte, []int)
Deprecated: Use PrimitiveBlock.ProtoReflect.Descriptor instead.
func (*PrimitiveBlock) GetGranularity ¶
func (x *PrimitiveBlock) GetGranularity() int32
func (*PrimitiveBlock) GetLatOffset ¶
func (x *PrimitiveBlock) GetLatOffset() int64
func (*PrimitiveBlock) GetLonOffset ¶
func (x *PrimitiveBlock) GetLonOffset() int64
func (*PrimitiveBlock) GetPrimitivegroup ¶
func (x *PrimitiveBlock) GetPrimitivegroup() []*PrimitiveGroup
func (*PrimitiveBlock) GetStringtable ¶
func (x *PrimitiveBlock) GetStringtable() *StringTable
func (*PrimitiveBlock) ProtoMessage ¶
func (*PrimitiveBlock) ProtoMessage()
func (*PrimitiveBlock) ProtoReflect ¶
func (x *PrimitiveBlock) ProtoReflect() protoreflect.Message
func (*PrimitiveBlock) Reset ¶
func (x *PrimitiveBlock) Reset()
func (*PrimitiveBlock) ResetVT ¶
func (m *PrimitiveBlock) ResetVT()
func (*PrimitiveBlock) ReturnToVTPool ¶
func (m *PrimitiveBlock) ReturnToVTPool()
func (*PrimitiveBlock) String ¶
func (x *PrimitiveBlock) String() string
func (*PrimitiveBlock) UnmarshalVT ¶
func (m *PrimitiveBlock) UnmarshalVT(dAtA []byte) error
type PrimitiveGroup ¶
type PrimitiveGroup struct {
Nodes []*Node `protobuf:"bytes,1,rep,name=nodes" json:"nodes,omitempty"`
Dense *DenseNodes `protobuf:"bytes,2,opt,name=dense" json:"dense,omitempty"`
Ways []*Way `protobuf:"bytes,3,rep,name=ways" json:"ways,omitempty"`
Relations []*Relation `protobuf:"bytes,4,rep,name=relations" json:"relations,omitempty"`
// contains filtered or unexported fields
}
Group of OSMPrimitives. All primitives in a group must be the same type.
func PrimitiveGroupFromVTPool ¶
func PrimitiveGroupFromVTPool() *PrimitiveGroup
func (*PrimitiveGroup) Descriptor
deprecated
func (*PrimitiveGroup) Descriptor() ([]byte, []int)
Deprecated: Use PrimitiveGroup.ProtoReflect.Descriptor instead.
func (*PrimitiveGroup) GetDense ¶
func (x *PrimitiveGroup) GetDense() *DenseNodes
func (*PrimitiveGroup) GetNodes ¶
func (x *PrimitiveGroup) GetNodes() []*Node
func (*PrimitiveGroup) GetRelations ¶
func (x *PrimitiveGroup) GetRelations() []*Relation
func (*PrimitiveGroup) GetWays ¶
func (x *PrimitiveGroup) GetWays() []*Way
func (*PrimitiveGroup) ProtoMessage ¶
func (*PrimitiveGroup) ProtoMessage()
func (*PrimitiveGroup) ProtoReflect ¶
func (x *PrimitiveGroup) ProtoReflect() protoreflect.Message
func (*PrimitiveGroup) Reset ¶
func (x *PrimitiveGroup) Reset()
func (*PrimitiveGroup) ResetVT ¶
func (m *PrimitiveGroup) ResetVT()
func (*PrimitiveGroup) ReturnToVTPool ¶
func (m *PrimitiveGroup) ReturnToVTPool()
func (*PrimitiveGroup) String ¶
func (x *PrimitiveGroup) String() string
func (*PrimitiveGroup) UnmarshalVT ¶
func (m *PrimitiveGroup) UnmarshalVT(dAtA []byte) error
type Relation ¶
type Relation struct {
Id *int64 `protobuf:"varint,1,req,name=id" json:"id,omitempty"`
// Parallel arrays.
Keys []uint32 `protobuf:"varint,2,rep,packed,name=keys" json:"keys,omitempty"`
Vals []uint32 `protobuf:"varint,3,rep,packed,name=vals" json:"vals,omitempty"`
// Parallel arrays
RolesSid []int32 `protobuf:"varint,8,rep,packed,name=roles_sid,json=rolesSid" json:"roles_sid,omitempty"` // This should have been defined as uint32 for consistency, but it is now too late to change it
Memids []int64 `protobuf:"zigzag64,9,rep,packed,name=memids" json:"memids,omitempty"` // DELTA encoded
Types []Relation_MemberType `protobuf:"varint,10,rep,packed,name=types,enum=OSMPBF.Relation_MemberType" json:"types,omitempty"`
// contains filtered or unexported fields
}
func RelationFromVTPool ¶
func RelationFromVTPool() *Relation
func (*Relation) Descriptor
deprecated
func (*Relation) GetRolesSid ¶
func (*Relation) GetTypes ¶
func (x *Relation) GetTypes() []Relation_MemberType
func (*Relation) ProtoMessage ¶
func (*Relation) ProtoMessage()
func (*Relation) ProtoReflect ¶
func (x *Relation) ProtoReflect() protoreflect.Message
func (*Relation) ReturnToVTPool ¶
func (m *Relation) ReturnToVTPool()
func (*Relation) UnmarshalVT ¶
type Relation_MemberType ¶
type Relation_MemberType int32
const ( Relation_NODE Relation_MemberType = 0 Relation_WAY Relation_MemberType = 1 Relation_RELATION Relation_MemberType = 2 )
func (Relation_MemberType) Descriptor ¶
func (Relation_MemberType) Descriptor() protoreflect.EnumDescriptor
func (Relation_MemberType) Enum ¶
func (x Relation_MemberType) Enum() *Relation_MemberType
func (Relation_MemberType) EnumDescriptor
deprecated
func (Relation_MemberType) EnumDescriptor() ([]byte, []int)
Deprecated: Use Relation_MemberType.Descriptor instead.
func (Relation_MemberType) Number ¶
func (x Relation_MemberType) Number() protoreflect.EnumNumber
func (Relation_MemberType) String ¶
func (x Relation_MemberType) String() string
func (Relation_MemberType) Type ¶
func (Relation_MemberType) Type() protoreflect.EnumType
func (*Relation_MemberType) UnmarshalJSON
deprecated
func (x *Relation_MemberType) UnmarshalJSON(b []byte) error
Deprecated: Do not use.
type StringTable ¶
type StringTable struct {
S [][]byte `protobuf:"bytes,1,rep,name=s" json:"s,omitempty"`
// contains filtered or unexported fields
}
func StringTableFromVTPool ¶ added in v0.1.1
func StringTableFromVTPool() *StringTable
func (*StringTable) Descriptor
deprecated
func (*StringTable) Descriptor() ([]byte, []int)
Deprecated: Use StringTable.ProtoReflect.Descriptor instead.
func (*StringTable) GetS ¶
func (x *StringTable) GetS() [][]byte
func (*StringTable) ProtoMessage ¶
func (*StringTable) ProtoMessage()
func (*StringTable) ProtoReflect ¶
func (x *StringTable) ProtoReflect() protoreflect.Message
func (*StringTable) Reset ¶
func (x *StringTable) Reset()
func (*StringTable) ResetVT ¶ added in v0.1.1
func (m *StringTable) ResetVT()
func (*StringTable) ReturnToVTPool ¶ added in v0.1.1
func (m *StringTable) ReturnToVTPool()
func (*StringTable) String ¶
func (x *StringTable) String() string
func (*StringTable) UnmarshalVT ¶
func (m *StringTable) UnmarshalVT(dAtA []byte) error
type Way ¶
type Way struct {
Id *int64 `protobuf:"varint,1,req,name=id" json:"id,omitempty"`
// Parallel arrays.
Keys []uint32 `protobuf:"varint,2,rep,packed,name=keys" json:"keys,omitempty"`
Vals []uint32 `protobuf:"varint,3,rep,packed,name=vals" json:"vals,omitempty"`
Refs []int64 `protobuf:"zigzag64,8,rep,packed,name=refs" json:"refs,omitempty"` // DELTA coded
// contains filtered or unexported fields
}
func WayFromVTPool ¶
func WayFromVTPool() *Way
func (*Way) Descriptor
deprecated
func (*Way) ProtoMessage ¶
func (*Way) ProtoMessage()
func (*Way) ProtoReflect ¶
func (x *Way) ProtoReflect() protoreflect.Message
func (*Way) ReturnToVTPool ¶
func (m *Way) ReturnToVTPool()
func (*Way) UnmarshalVT ¶
Click to show internal directories.
Click to hide internal directories.